@@ -40,7 +40,7 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::InitCachePolicy()
 
     __GMM_ASSERTPTR(pCachePolicy, GMM_ERROR);
 
-#define DEFINE_CACHE_ELEMENT(usage, llc, ellc, l3, wt, age, lecc_scc, l3_scc, sso, cos, hdcl1) DEFINE_CP_ELEMENT(usage, llc, ellc, l3, wt, age, 0, lecc_scc, l3_scc, 0, sso, cos, hdcl1, 0, 0, 0, 0)
+#define DEFINE_CACHE_ELEMENT(usage, llc, ellc, l3, wt, age, lecc_scc, l3_scc, sso, cos, hdcl1) DEFINE_CP_ELEMENT(usage, llc, ellc, l3, wt, age, 0, lecc_scc, l3_scc, 0, sso, cos, hdcl1, 0, 0, 0, 0, 0)
 #include "GmmGen10CachePolicy.h"
 
 #define TC_LLC (1)
@@ -67,7 +67,7 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::InitCachePolicy()
 
         uint32_t                      CurrentMaxIndex        = 0;
         uint32_t                      CurrentMaxHDCL1Index   = GMM_GEN10_HDCL1_MOCS_INDEX_START - 1; // define constant
-        GMM_CACHE_POLICY_TBL_ELEMENT *pCachePolicyTlbElement = pGmmGlobalContext->GetCachePolicyTlbElement();
+        GMM_CACHE_POLICY_TBL_ELEMENT *pCachePolicyTlbElement = pGmmLibContext->GetCachePolicyTlbElement();
 
         // index 0 is uncached.
         {
@@ -91,7 +91,7 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::InitCachePolicy()
             bool                         CachePolicyError = false;
             int32_t                      CPTblIdx         = -1;
             uint32_t                     j                = 0;
-            uint32_t                     PTEValue         = 0;
+            uint64_t                     PTEValue         = 0;
             GMM_CACHE_POLICY_TBL_ELEMENT UsageEle         = {0};
             UsageEle.LeCC.Reserved                        = 0; // Reserved bits zeroe'd, this is so we
                                                                // we can compare the unioned LeCC.DwordValue.
@@ -224,7 +224,8 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::InitCachePolicy()
                 CachePolicyError = true;
             }
 
-            pCachePolicy[Usage].PTE.DwordValue = PTEValue;
+            pCachePolicy[Usage].PTE.DwordValue     = PTEValue & 0xFFFFFFFF;
+            pCachePolicy[Usage].PTE.HighDwordValue = 0;
 
             pCachePolicy[Usage].MemoryObjectOverride.Gen10.Index = CPTblIdx;
 
@@ -254,7 +255,10 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetPATInitWA()
     GMM_STATUS Status = GMM_SUCCESS;
 
 #if(defined(__GMM_KMD__))
-    
+    if(pGmmLibContext->GetGtSysInfoPtr()->EdramSizeInKb)
+    {
+        const_cast<WA_TABLE &>(pGmmLibContext->GetWaTable()).WaNoMocsEllcOnly = 1;
+    }
 #else
     Status = GMM_ERROR;
 #endif
@@ -346,10 +350,9 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
     uint8_t              Age                        = 1;
     uint8_t              ServiceClass               = 0;
     int32_t *            pPrivatePATTableMemoryType = NULL;
-    pPrivatePATTableMemoryType                      = pGmmGlobalContext->GetPrivatePATTableMemoryType();
-
-    __GMM_ASSERT(pGmmGlobalContext->GetSkuTable().FtrIA32eGfxPTEs);
+    pPrivatePATTableMemoryType                      = pGmmLibContext->GetPrivatePATTableMemoryType();
 
+    __GMM_ASSERT(pGmmLibContext->GetSkuTable().FtrIA32eGfxPTEs);
     for(i = 0; i < GMM_NUM_GFX_PAT_TYPES; i++)
     {
         pPrivatePATTableMemoryType[i] = -1;
@@ -360,7 +363,7 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
     {
         GMM_PRIVATE_PAT PAT = {0};
 
-        if(pGmmGlobalContext->GetWaTable().FtrMemTypeMocsDeferPAT)
+	if(pGmmLibContext->GetWaTable().WaNoMocsEllcOnly)
         {
             GfxTargetCache = GMM_GFX_TC_ELLC_ONLY;
         }
@@ -372,12 +375,12 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
         switch(i)
         {
             case PAT0:
-                if(pGmmGlobalContext->GetWaTable().WaGttPat0)
-                {
-                    if(pGmmGlobalContext->GetWaTable().WaGttPat0WB)
-                    {
+                if(pGmmLibContext->GetWaTable().WaGttPat0)
+		{
+                    if(pGmmLibContext->GetWaTable().WaGttPat0WB)			 
+	            {
                         GfxMemType = GMM_GFX_WB;
-                        if(GFX_IS_ATOM_PLATFORM)
+                        if(GFX_IS_ATOM_PLATFORM(pGmmLibContext))
                         {
                             PAT.PreGen10.Snoop = 1;
                         }
@@ -392,7 +395,7 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
                 else // if GTT is not tied to PAT0 then WaGttPat0WB is NA
                 {
                     GfxMemType = GMM_GFX_WB;
-                    if(GFX_IS_ATOM_PLATFORM)
+                    if(GFX_IS_ATOM_PLATFORM(pGmmLibContext))
                     {
                         PAT.PreGen10.Snoop = 1;
                     }
@@ -401,10 +404,10 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
                 break;
 
             case PAT1:
-                if(pGmmGlobalContext->GetWaTable().WaGttPat0 && !pGmmGlobalContext->GetWaTable().WaGttPat0WB)
+                if(pGmmLibContext->GetWaTable().WaGttPat0 && !pGmmLibContext->GetWaTable().WaGttPat0WB)		
                 {
                     GfxMemType = GMM_GFX_WB;
-                    if(GFX_IS_ATOM_PLATFORM)
+                    if(GFX_IS_ATOM_PLATFORM(pGmmLibContext))
                     {
                         PAT.PreGen10.Snoop = 1;
                     }
@@ -460,4 +463,4 @@ GMM_STATUS GmmLib::GmmGen10CachePolicy::SetupPAT()
     Status = GMM_ERROR;
 #endif
     return Status;
-}
\ No newline at end of file
+}
