@@ -26,6 +26,10 @@ OTHER DEALINGS IN THE SOFTWARE.
 #include "Internal/Common/Texture/GmmGen11TextureCalc.h"
 #include "Internal/Common/Texture/GmmGen12TextureCalc.h"
 
+GMM_MIPTAIL_SLOT_OFFSET MipTailSlotOffset1DSurface[15][5] = GEN11_MIPTAIL_SLOT_OFFSET_1D_SURFACE;
+GMM_MIPTAIL_SLOT_OFFSET MipTailSlotOffset2DSurface[15][5] = GEN11_MIPTAIL_SLOT_OFFSET_2D_SURFACE;
+GMM_MIPTAIL_SLOT_OFFSET MipTailSlotOffset3DSurface[15][5] = GEN11_MIPTAIL_SLOT_OFFSET_3D_SURFACE;
+
 /////////////////////////////////////////////////////////////////////////////////////
 /// Calculates height of the 2D mip layout on Gen9
 ///
@@ -41,9 +45,9 @@ uint32_t GmmLib::GmmGen12TextureCalc::Get2DMipMapHeight(GMM_TEXTURE_INFO *pTexIn
     uint8_t  Compressed;
     GMM_DPF_ENTER;
 
-    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
+    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo, pGmmLibContext);
 
-    Compressed = GmmIsCompressed(pTexInfo->Format);
+    Compressed = GmmIsCompressed(pGmmLibContext, pTexInfo->Format);
     MipHeight  = pTexInfo->BaseHeight;
     MipLevel   = pTexInfo->MaxLod;
     VAlign     = pTexInfo->Alignment.VAlign;
@@ -145,18 +149,21 @@ uint32_t GmmLib::GmmGen12TextureCalc::Get2DMipMapHeight(GMM_TEXTURE_INFO *pTexIn
 GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
                                                    GMM_TEXTURE_INFO *pAuxTexInfo)
 {
-
-    
-    if(pAuxTexInfo->Flags.Gpu.__NonMsaaLinearCCS)
+    if(pGmmLibContext->GetSkuTable().FtrFlatPhysCCS && !pSurf->Flags.Gpu.ProceduralTexture)
+    {
+        //No CCS allocation for lossless compression (exclude AMFS CCS).
+        return GMM_SUCCESS;
+    }    
+    else if(pAuxTexInfo->Flags.Gpu.__NonMsaaLinearCCS)
     {
         GMM_TEXTURE_INFO         Surf      = *pSurf;
-        const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pSurf);
+        const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pSurf, pGmmLibContext);
         pAuxTexInfo->Flags.Info.TiledW     = 0;
         pAuxTexInfo->Flags.Info.TiledYf    = 0;
         pAuxTexInfo->Flags.Info.TiledX     = 0;
         pAuxTexInfo->Flags.Info.Linear     = 1;
-        GMM_SET_64KB_TILE(pAuxTexInfo->Flags, 0);
-        GMM_SET_4KB_TILE(pAuxTexInfo->Flags, 0);
+        GMM_SET_64KB_TILE(pAuxTexInfo->Flags, 0, pGmmLibContext);
+        GMM_SET_4KB_TILE(pAuxTexInfo->Flags, 0, pGmmLibContext);
 
         pAuxTexInfo->ArraySize    = Surf.ArraySize;
         pAuxTexInfo->BitsPerPixel = 8;
@@ -167,7 +174,9 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
         ((Surf.Flags.Gpu.Depth || Surf.Flags.Gpu.SeparateStencil ||
           GMM_IS_64KB_TILE(Surf.Flags) || Surf.Flags.Info.TiledYf) ?
          1 :
-         Surf.MSAA.NumSamples); // MSAA (non-Depth/Stencil) RT samples stored as array planes.
+         Surf.MSAA.NumSamples) *                                                                                         // MSAA (non-Depth/Stencil) RT samples stored as array planes.
+        ((GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (Surf.MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
+         (GMM_IS_64KB_TILE(Surf.Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (Surf.MSAA.NumSamples == 8)) ? 2 : 1);
 
         if(GMM_IS_64KB_TILE(Surf.Flags) || Surf.Flags.Info.TiledYf)
         {
@@ -227,6 +236,11 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
                 pAuxTexInfo->Alignment.QPitch = GFX_ULONG_CAST(pAuxTexInfo->Size); //HW doesn't use QPitch for Aux except MCS, how'd AMFS get sw-filled non-zero QPitch?
 
                 pAuxTexInfo->Size *= ExpandedArraySize;
+                if(Surf.MSAA.NumSamples && !pGmmLibContext->GetSkuTable().FtrTileY)
+                {
+                    //MSAA Qpitch is sample-distance, multiply NumSamples in a tile
+                    pAuxTexInfo->Size *= GFX_MIN(Surf.MSAA.NumSamples, 4);
+                }
             }
             else
             {
@@ -236,6 +250,7 @@ GMM_STATUS GmmLib::GmmGen12TextureCalc::FillTexCCS(GMM_TEXTURE_INFO *pSurf,
         pAuxTexInfo->Pitch                   = 0;
         pAuxTexInfo->Type                    = RESOURCE_BUFFER;
         pAuxTexInfo->Alignment               = {0};
+        __GMM_ASSERT(ExpandedArraySize || (pAuxTexInfo->Size == 0));
         pAuxTexInfo->Alignment.QPitch        = GFX_ULONG_CAST(pAuxTexInfo->Size) / ExpandedArraySize;
         pAuxTexInfo->Alignment.BaseAlignment = GMM_KBYTE(4);                            //TODO: TiledResource?
         pAuxTexInfo->Size                    = GFX_ALIGN(pAuxTexInfo->Size, PAGE_SIZE); //page-align final size
@@ -280,7 +295,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     __GMM_ASSERTPTR(pTexInfo, GMM_ERROR);
     __GMM_ASSERTPTR(pRestrictions, GMM_ERROR);
 
-    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
+    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo, pGmmLibContext);
 
     BitsPerPixel = pTexInfo->BitsPerPixel;
     //TODO: Deprecate TileY usage
@@ -308,8 +323,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
       (GMM_IS_64KB_TILE(pTexInfo->Flags) || pTexInfo->Flags.Info.TiledYf)) ? // MSAA Ys/Yf samples are ALSO stored as array planes, calculate size for single sample and expand it later.
      1 :
      pTexInfo->MSAA.NumSamples) *                                                                                              // MSAA (non-Depth/Stencil) RT samples stored as array planes.
-    ((GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmGlobalContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
-     (GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmGlobalContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 8)) ? 2 : 1);
+    ((GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 16)) ? 4 : // MSAA x8/x16 stored as pseudo array planes each with 4x samples
+     (GMM_IS_64KB_TILE(pTexInfo->Flags) && !pGmmLibContext->GetSkuTable().FtrTileY && (pTexInfo->MSAA.NumSamples == 8)) ? 2 : 1);
 
     if(GMM_IS_64KB_TILE(pTexInfo->Flags) || pTexInfo->Flags.Info.TiledYf)
     {
@@ -349,7 +364,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
 
     GetCompressionBlockDimensions(pTexInfo->Format, &CompressWidth, &CompressHeight, &CompressDepth);
 
-    Compress = GmmIsCompressed(pTexInfo->Format);
+    Compress = GmmIsCompressed(pGmmLibContext, pTexInfo->Format);
 
     /////////////////////////////////
     // Calculate Block Surface Height
@@ -359,7 +374,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     {
         uint32_t Alignment = VAlign;
         if((pTexInfo->Type == RESOURCE_3D && !pTexInfo->Flags.Info.Linear) ||
-           (pTexInfo->Flags.Gpu.S3dDx && pGmmGlobalContext->GetSkuTable().FtrDisplayEngineS3d))
+           (pTexInfo->Flags.Gpu.S3dDx && pGmmLibContext->GetSkuTable().FtrDisplayEngineS3d) ||
+	   (pTexInfo->Flags.Wa.MediaPipeUsage))
         {
             Alignment = pPlatform->TileInfo[pTexInfo->TileMode].LogicalTileHeight;
         }
@@ -459,7 +475,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTex2D(GMM_TEXTURE_INFO *
     }
 
     // For Non-planar surfaces, the alignment is done on the entire height of the allocation
-    if(pGmmGlobalContext->GetWaTable().WaAlignYUVResourceToLCU &&
+    if(pGmmLibContext->GetWaTable().WaAlignYUVResourceToLCU &&
        GmmIsYUVFormatLCUAligned(pTexInfo->Format) &&
        !GmmIsPlanar(pTexInfo->Format))
     {
@@ -503,7 +519,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
     __GMM_ASSERTPTR(pTexInfo, GMM_ERROR);
     __GMM_ASSERTPTR(pRestrictions, GMM_ERROR);
     __GMM_ASSERT(!pTexInfo->Flags.Info.TiledW);
-    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
+    const GMM_PLATFORM_INFO *pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo, pGmmLibContext);
 
     BitsPerPixel = pTexInfo->BitsPerPixel;
     AlignedWidth = GFX_ULONG_CAST(pTexInfo->BaseWidth);
@@ -715,8 +731,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
                 pTexInfo->Flags.Info.TiledYf = 0;
                 pTexInfo->Flags.Info.TiledX  = 0;
                 pTexInfo->Flags.Info.Linear  = 1;
-                GMM_SET_64KB_TILE(pTexInfo->Flags, 0);
-                GMM_SET_4KB_TILE(pTexInfo->Flags, 0);
+                GMM_SET_64KB_TILE(pTexInfo->Flags, 0, pGmmLibContext);
+                GMM_SET_4KB_TILE(pTexInfo->Flags, 0, pGmmLibContext);
             }
 
             UVPacked = true;
@@ -766,8 +782,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
             pTexInfo->Flags.Info.TiledX           = 0;
             pTexInfo->Flags.Info.Linear           = 1;
             pTexInfo->OffsetInfo.Plane.NoOfPlanes = 1;
-            GMM_SET_64KB_TILE(pTexInfo->Flags, 0);
-            GMM_SET_4KB_TILE(pTexInfo->Flags, 0);
+            GMM_SET_64KB_TILE(pTexInfo->Flags, 0, pGmmLibContext);
+            GMM_SET_4KB_TILE(pTexInfo->Flags, 0, pGmmLibContext);
 
             break;
         }
@@ -838,8 +854,10 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
 
     AdjustedVHeight = VHeight;
 
+    FindMipTailStartLod(pTexInfo);
+
     // In case of Planar surfaces, only the last Plane has to be aligned to 64 for LCU access
-    if(pGmmGlobalContext->GetWaTable().WaAlignYUVResourceToLCU && GmmIsYUVFormatLCUAligned(pTexInfo->Format) && VHeight > 0)
+    if(pGmmLibContext->GetWaTable().WaAlignYUVResourceToLCU && GmmIsYUVFormatLCUAligned(pTexInfo->Format) && VHeight > 0)
     {
         AdjustedVHeight = GFX_ALIGN(VHeight, GMM_SCANLINES(GMM_MAX_LCU_SIZE));
         Height += AdjustedVHeight - VHeight;
@@ -852,16 +870,16 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
     if(GMM_IS_TILED(pPlatform->TileInfo[pTexInfo->TileMode]) &&
        !pTexInfo->Flags.Gpu.__NonMsaaTileYCcs)
     {
-        uint32_t TileHeight = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
-        uint32_t TileWidth  = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileWidth;
+        uint32_t TileHeight = pGmmLibContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
+        uint32_t TileWidth  = pGmmLibContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileWidth;
 
         pTexInfo->OffsetInfo.Plane.IsTileAlignedPlanes = true;
 
-        if(pTexInfo->Flags.Gpu.CCS)
+        if(pTexInfo->Flags.Gpu.CCS && !pGmmLibContext->GetSkuTable().FtrFlatPhysCCS)
         {
             //U/V must be aligned to AuxT granularity, 4x pitchalign enforces 16K-align,
             //add extra padding for 64K AuxT
-            TileHeight *= (!GMM_IS_64KB_TILE(pTexInfo->Flags) && !WA16K) ? 4 : 1;
+            TileHeight *= (!GMM_IS_64KB_TILE(pTexInfo->Flags) && !WA16K(pGmmLibContext)) ? 4 : 1;
         }
 
         if(pTexInfo->Format == GMM_FORMAT_IMC2 || // IMC2, IMC4 needs even tile columns
@@ -888,7 +906,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
     }
     else if(pTexInfo->Flags.Gpu.__NonMsaaTileYCcs)
     {
-        uint32_t TileHeight = pGmmGlobalContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
+        uint32_t TileHeight = pGmmLibContext->GetPlatformInfo().TileInfo[pTexInfo->TileMode].LogicalTileHeight;
 
         BitsPerPixel = 8;
 
@@ -923,7 +941,15 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::FillTexPlanar(GMM_TEXTURE_IN
 
         Height = YHeight + VHeight;
     }
-
+    
+    if(pTexInfo->Flags.Info.RedecribedPlanes)
+    {
+        if(false == RedescribeTexturePlanes(pTexInfo, &WidthBytesPhysical))
+        {
+            __GMM_ASSERT(FALSE);
+        }
+    }
+    
     if((Status = // <-- Note assignment.
         FillTexPitchAndSize(
         pTexInfo, WidthBytesPhysical, Height, pRestrictions)) == GMM_SUCCESS)
@@ -961,7 +987,7 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::GetCCSScaleFactor(GMM_TEXTUR
                                                                       CCS_UNIT &        ScaleFactor)
 {
     GMM_STATUS           Status     = GMM_SUCCESS;
-    GMM_TEXTURE_ALIGN_EX TexAlignEx = static_cast<PlatformInfoGen12 *>(pGmmGlobalContext->GetPlatformInfoObj())->GetExTextureAlign();
+    GMM_TEXTURE_ALIGN_EX TexAlignEx = static_cast<PlatformInfoGen12 *>(pGmmLibContext->GetPlatformInfoObj())->GetExTextureAlign();
     uint32_t             CCSModeIdx = 0;
 
     if(pTexInfo->Flags.Info.TiledYf || GMM_IS_64KB_TILE(pTexInfo->Flags)) //pTexInfo is RT Surf
@@ -989,8 +1015,8 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::GetCCSExMode(GMM_TEXTURE_INF
 {
     if(GMM_IS_4KB_TILE(AuxSurf->Flags) || GMM_IS_64KB_TILE(AuxSurf->Flags) || AuxSurf->Flags.Info.Linear)
     {
-        if(pGmmGlobalContext->GetSkuTable().FtrLinearCCS)
-        {
+        if(pGmmLibContext->GetSkuTable().FtrLinearCCS)
+ 	{
             AuxSurf->Flags.Gpu.__NonMsaaLinearCCS = 1;
         }
         else
@@ -1074,8 +1100,8 @@ uint32_t GMM_STDCALL GmmLib::GmmGen12TextureCalc::ScaleFCRectHeight(GMM_TEXTURE_
     uint32_t ScaledHeight = Height;
     if(pTexInfo->Flags.Gpu.CCS)
     {
-        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmGlobalContext->GetPlatformInfoObj())->GetFCRectAlign();
-        uint8_t   index       = FCMaxModes;
+        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmLibContext->GetPlatformInfoObj())->GetFCRectAlign();
+	uint8_t   index       = FCMaxModes;
         if((index = FCMode(pTexInfo->TileMode, pTexInfo->BitsPerPixel)) < FCMaxModes)
         {
             ScaledHeight = GFX_ALIGN(ScaledHeight, FCRectAlign[index].Align.Height);
@@ -1095,7 +1121,7 @@ uint64_t GMM_STDCALL GmmLib::GmmGen12TextureCalc::ScaleFCRectWidth(GMM_TEXTURE_I
     uint64_t ScaledWidth = Width;
     if(pTexInfo->Flags.Gpu.CCS)
     {
-        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmGlobalContext->GetPlatformInfoObj())->GetFCRectAlign();
+        CCS_UNIT *FCRectAlign = static_cast<PlatformInfoGen12 *>(pGmmLibContext->GetPlatformInfoObj())->GetFCRectAlign();	    
         uint8_t   index       = FCMaxModes;
         if((index = FCMode(pTexInfo->TileMode, pTexInfo->BitsPerPixel)) < FCMaxModes)
         {
@@ -1190,3 +1216,126 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmGen12TextureCalc::MSAACCSUsage(GMM_TEXTURE_INF
     }
     return Status;
 }
+
+
+/////////////////////////////////////////////////////////////////////////////////////
+/// Returns the mip offset of given LOD in Mip Tail
+///
+/// @param[in]  pTexInfo: ptr to ::GMM_TEXTURE_INFO,
+///             MipLevel: mip-map level
+///
+/// @return     offset value of LOD in bytes
+/////////////////////////////////////////////////////////////////////////////////////
+uint32_t GmmLib::GmmGen12TextureCalc::GetMipTailByteOffset(GMM_TEXTURE_INFO *pTexInfo,
+                                                           uint32_t          MipLevel)
+{
+    uint32_t ByteOffset = 0, Slot = 0xff;
+
+    GMM_DPF_ENTER;
+
+    if(pGmmLibContext->GetSkuTable().FtrTileY)
+    {
+        return GmmGen11TextureCalc::GetMipTailByteOffset(pTexInfo, MipLevel);
+    }
+    // 3D textures follow the Gen10 mip tail format
+    if(!pGmmLibContext->GetSkuTable().FtrStandardMipTailFormat)
+    {
+        return GmmGen9TextureCalc::GetMipTailByteOffset(pTexInfo, MipLevel);
+    }
+
+    // Til64 is the only format which supports MipTail on FtrTileY disabled platforms
+    __GMM_ASSERT(pTexInfo->Flags.Info.Tile64);
+    // Mipped MSAA is not supported for Tile64
+    __GMM_ASSERT(pTexInfo->MSAA.NumSamples <= 1);
+
+    if((pTexInfo->Type == RESOURCE_1D) || (pTexInfo->Type == RESOURCE_3D) || (pTexInfo->Type == RESOURCE_2D || pTexInfo->Type == RESOURCE_CUBE))
+    {
+        Slot = MipLevel - pTexInfo->Alignment.MipTailStartLod;
+    }
+
+    // Miptail Slot layout in Tile64: as per specifications
+    // Byteoffset varies based on bpp for tile64 format, so any caller who needs to use byteoffset needs to call cpuswizzle with corresponding geomteric offsets
+    // Returning ByteOffset as 0 for Tile64 always
+
+    // GMM_DPF_CRITICAL("Miptail byte offset requested for Tile64 \r\n");
+    GMM_DPF_EXIT;
+
+    // return ByteOffset=0, i.e return start of miptail for any address within packed miptail
+    return (ByteOffset);
+}
+
+void GmmLib::GmmGen12TextureCalc::GetMipTailGeometryOffset(GMM_TEXTURE_INFO *pTexInfo,
+                                                           uint32_t          MipLevel,
+                                                           uint32_t *        OffsetX,
+                                                           uint32_t *        OffsetY,
+                                                           uint32_t *        OffsetZ)
+{
+    uint32_t ArrayIndex = 0;
+    uint32_t Slot       = 0;
+
+    GMM_DPF_ENTER;
+
+    if(pGmmLibContext->GetSkuTable().FtrTileY)
+    {
+        return GmmGen11TextureCalc::GetMipTailGeometryOffset(pTexInfo, MipLevel, OffsetX, OffsetY, OffsetZ);
+    }
+
+    // Til64 is the only format which supports MipTail on FtrTileY disabled platforms
+    __GMM_ASSERT(pTexInfo->Flags.Info.Tile64);
+    // Mipped MSAA is not supported for Tile64
+    __GMM_ASSERT(pTexInfo->MSAA.NumSamples <= 1);
+
+    switch(pTexInfo->BitsPerPixel)
+    {
+        case 128:
+            ArrayIndex = 0;
+            break;
+        case 64:
+            ArrayIndex = 1;
+            break;
+        case 32:
+            ArrayIndex = 2;
+            break;
+        case 16:
+            ArrayIndex = 3;
+            break;
+        case 8:
+            ArrayIndex = 4;
+            break;
+        default:
+            __GMM_ASSERT(0);
+            break;
+    }
+
+
+    // FtrTileY disabled platforms: platforms which support Tile4/Tile64 tiled formats
+    if(pTexInfo->Type == RESOURCE_1D)
+    {
+        Slot = MipLevel - pTexInfo->Alignment.MipTailStartLod;
+
+        *OffsetX = MipTailSlotOffset1DSurface[Slot][ArrayIndex].X * pTexInfo->BitsPerPixel / 8;
+        *OffsetY = MipTailSlotOffset1DSurface[Slot][ArrayIndex].Y;
+        *OffsetZ = MipTailSlotOffset1DSurface[Slot][ArrayIndex].Z;
+    }
+    else if(pTexInfo->Type == RESOURCE_2D || pTexInfo->Type == RESOURCE_CUBE)
+    {
+        // Mipped MSAA is not supported on Tile64, so need not account for MSAA here
+        Slot = MipLevel - pTexInfo->Alignment.MipTailStartLod;
+
+        *OffsetX = MipTailSlotOffset2DSurface[Slot][ArrayIndex].X * pTexInfo->BitsPerPixel / 8;
+        *OffsetY = MipTailSlotOffset2DSurface[Slot][ArrayIndex].Y;
+        *OffsetZ = MipTailSlotOffset2DSurface[Slot][ArrayIndex].Z;
+    }
+    else if(pTexInfo->Type == RESOURCE_3D)
+    {
+        Slot = MipLevel - pTexInfo->Alignment.MipTailStartLod;
+
+        *OffsetX = MipTailSlotOffset3DSurface[Slot][ArrayIndex].X * pTexInfo->BitsPerPixel / 8;
+        *OffsetY = MipTailSlotOffset3DSurface[Slot][ArrayIndex].Y;
+        *OffsetZ = MipTailSlotOffset3DSurface[Slot][ArrayIndex].Z;
+    }
+
+    GMM_DPF_EXIT;
+    return;
+}
+
