@@ -57,7 +57,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 //
 //-----------------------------------------------------------------------------
 // Gmmlib 2.0 TODO[Low] Move to Class and Inline function handling.
-GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
+GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo,GMM_LIB_CONTEXT* pGmmLibContext)
 {
     uint32_t                   UnitAlignWidth = 0;
     uint32_t                   UnitAlignHeight = 0;
@@ -66,9 +66,30 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
     GMM_TEXTURE_CALC        *pTextureCalc;
 
     GMM_DPF_ENTER;
+    __GMM_ASSERTPTR(pGmmLibContext,GMM_ERROR);
 
     __GMM_ASSERTPTR(pTexInfo, GMM_ERROR);
-    __GMM_ASSERTPTR(pGmmGlobalContext, GMM_ERROR);
+
+#define SET_ALIGN_FACTOR(Xxx, Bytes)                            \
+    if(!pGmmLibContext->GetSkuTable().FtrTileY)              \
+    {                                                           \
+        UnitAlign##Xxx =                                        \
+            (pTexInfo->BitsPerPixel == 128) ? Bytes/16 :        \
+            (pTexInfo->BitsPerPixel ==  64) ? Bytes/8 :         \
+            (pTexInfo->BitsPerPixel ==  32) ? Bytes/4 :         \
+            (pTexInfo->BitsPerPixel ==  16) ? Bytes/2 : Bytes ; \
+                                                                \
+        if(!pTexInfo->Flags.Info.Linear &&  \
+           (pTexInfo->BitsPerPixel == 24 || pTexInfo->BitsPerPixel == 48 || pTexInfo->BitsPerPixel == 96)) \
+        {                                                       \
+            UnitAlign##Xxx = 16;                                \
+        }                                                       \
+        else if (pTexInfo->Flags.Info.Linear && \
+            (pTexInfo->BitsPerPixel == 24 || pTexInfo->BitsPerPixel == 48 || pTexInfo->BitsPerPixel == 96))\
+        {                                                       \
+            UnitAlign##Xxx = 128;                               \
+        }                                                       \
+    }
 
     if (!((pTexInfo->Format > GMM_FORMAT_INVALID) &&
         (pTexInfo->Format < GMM_RESOURCE_FORMATS)))
@@ -80,8 +101,8 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
     if( !pTexInfo->Alignment.HAlign &&
         !pTexInfo->Alignment.VAlign)
     {
-        pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo);
-        pTextureCalc = GMM_OVERRIDE_TEXTURE_CALC(pTexInfo);
+        pPlatform = GMM_OVERRIDE_PLATFORM_INFO(pTexInfo,pGmmLibContext);
+        pTextureCalc = GMM_OVERRIDE_TEXTURE_CALC(pTexInfo,pGmmLibContext);
 
         /// SKL TiledYf/Ys Surfaces //////////////////////////////////////////
         if( ((GFX_GET_CURRENT_RENDERCORE(pPlatform->Platform) >= IGFX_GEN9_CORE) &&
@@ -124,13 +145,27 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
                    !pTexInfo->Flags.Gpu.Depth &&
                    !pTexInfo->Flags.Gpu.SeparateStencil)
                 {
-                    switch(pTexInfo->MSAA.NumSamples)
+                    if(pGmmLibContext->GetSkuTable().FtrTileY)
                     {
-                        case 16: UnitAlignWidth /= 4; UnitAlignHeight /= 4; break;
-                        case 8:  UnitAlignWidth /= 4; UnitAlignHeight /= 2; break;
-                        case 4:  UnitAlignWidth /= 2; UnitAlignHeight /= 2; break;
-                        case 2:  UnitAlignWidth /= 2; break;
-                        default: __GMM_ASSERT(0);
+                        switch(pTexInfo->MSAA.NumSamples)
+                        {
+                            case 16: UnitAlignWidth /= 4; UnitAlignHeight /= 4; break;
+                            case 8:  UnitAlignWidth /= 4; UnitAlignHeight /= 2; break;
+                            case 4:  UnitAlignWidth /= 2; UnitAlignHeight /= 2; break;
+                            case 2:  UnitAlignWidth /= 2; break;
+                            default: __GMM_ASSERT(0);
+                        }
+                    }
+                    else
+                    {
+                        switch (pTexInfo->MSAA.NumSamples)
+                        {
+                            case 4:
+                            case 8:
+                            case 16: UnitAlignWidth /= 2; UnitAlignHeight /= 2; break;
+                            case 2:  UnitAlignWidth /= 2; break;
+                            default: __GMM_ASSERT(0);
+                        }
                     }
                 }
             }
@@ -151,7 +186,7 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
             }
 
             #undef SET_ALIGN_INFO
-            if (GmmIsCompressed(pTexInfo->Format))
+            if(GmmIsCompressed(pGmmLibContext, pTexInfo->Format))
             {
                 uint32_t   ElementWidth, ElementHeight, ElementDepth;
                 pTextureCalc->GetCompressionBlockDimensions(pTexInfo->Format, &ElementWidth, &ElementHeight, &ElementDepth);
@@ -166,6 +201,9 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
                 (pTexInfo->Type == RESOURCE_1D))
         {
             UnitAlignWidth = 64;
+
+            // Tile4/64
+            SET_ALIGN_FACTOR(Width, 128);
         }
         /// CCS ///////////////////////////////////////////////////////////
         else if (pTexInfo->Flags.Gpu.CCS &&
@@ -175,7 +213,7 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
             UnitAlignHeight = pPlatform->TexAlign.CCS.Align.Height;
 
             ALIGNMENT UnitAlign = { UnitAlignWidth , UnitAlignHeight, UnitAlignDepth };
-            pGmmGlobalContext->GetPlatformInfoObj()->ApplyExtendedTexAlign(pTexInfo->CCSModeAlign, UnitAlign);
+            pGmmLibContext->GetPlatformInfoObj()->ApplyExtendedTexAlign(pTexInfo->CCSModeAlign, UnitAlign);
 
             if (UnitAlign.Width != UnitAlignWidth ||
                 UnitAlign.Height != UnitAlignHeight ||
@@ -190,8 +228,11 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
         {
             UnitAlignWidth = pPlatform->TexAlign.YUV422.Width;
             UnitAlignHeight = pPlatform->TexAlign.YUV422.Height;
+
+            // For packed 8/16-bit formats alignment factor of 4 will give us < 16B so expand to 32B
+            SET_ALIGN_FACTOR(Width, 32);
         }
-        else if(GmmIsCompressed(pTexInfo->Format)) /////////////////////////////
+        else if(GmmIsCompressed(pGmmLibContext, pTexInfo->Format)) /////////////////////////////
         {
             uint32_t   ElementWidth, ElementHeight, ElementDepth;
 
@@ -233,11 +274,16 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
                     UnitAlignWidth = pPlatform->TexAlign.Depth_D16_UNORM_1x_4x_16x.Width;
                     UnitAlignHeight = pPlatform->TexAlign.Depth_D16_UNORM_1x_4x_16x.Height;
                 }
+
+                SET_ALIGN_FACTOR(Width, 16);
+
             }
             else
             {
                 UnitAlignWidth = pPlatform->TexAlign.Depth.Width;
                 UnitAlignHeight = pPlatform->TexAlign.Depth.Height;
+
+                SET_ALIGN_FACTOR(Width, 32);
             }
         }
         /// Separate Stencil //////////////////////////////////////////////
@@ -245,6 +291,9 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
         {
             UnitAlignWidth  = pPlatform->TexAlign.SeparateStencil.Width;
             UnitAlignHeight = pPlatform->TexAlign.SeparateStencil.Height;
+
+            SET_ALIGN_FACTOR(Width, 16);
+
         }
         /// Cross Adapter //////////////////////////////////////////////
         else if(pTexInfo->Flags.Info.XAdapter)
@@ -252,6 +301,10 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
             //Add cross adapter height restriction.
             UnitAlignHeight = pPlatform->TexAlign.XAdapter.Height;
             UnitAlignWidth = pPlatform->TexAlign.XAdapter.Width;
+
+            SET_ALIGN_FACTOR(Width, 128);
+
+            __GMM_ASSERT(pTexInfo->MaxLod == 0);
         }
         else if(((pTexInfo->Flags.Gpu.MCS &&
                   GFX_GET_CURRENT_RENDERCORE(pPlatform->Platform) >= IGFX_GEN12_CORE) ||
@@ -260,6 +313,8 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
         {
             UnitAlignWidth  = 16;
             UnitAlignHeight = 4;
+
+            SET_ALIGN_FACTOR(Width, 128);
         }
         else if(pTexInfo->Flags.Wa.__ForceOtherHVALIGN4)
         {
@@ -282,29 +337,31 @@ GMM_INLINE GMM_STATUS __GmmTexFillHAlignVAlign(GMM_TEXTURE_INFO *pTexInfo)
                 UnitAlignHeight = pPlatform->TexAlign.AllOther.Height;
 
                 // Let VAlign = 16, when bpp == 8 or 16 for both TileX and TileY on BDW
-                if ((GmmGetWaTable(pGmmGlobalContext)->WaUseVAlign16OnTileXYBpp816) &&
+                if ((GmmGetWaTable(pGmmLibContext)->WaUseVAlign16OnTileXYBpp816) &&
                     (pTexInfo->BitsPerPixel == 8 || pTexInfo->BitsPerPixel == 16) &&
                     (pTexInfo->Flags.Info.TiledX || pTexInfo->Flags.Info.TiledY))
                 {
                     UnitAlignHeight = 16;
                 }
 
-                if((GmmGetWaTable(pGmmGlobalContext)->Wa32bppTileY2DColorNoHAlign4) &&
+                if((GmmGetWaTable(pGmmLibContext)->Wa32bppTileY2DColorNoHAlign4) &&
                    (pTexInfo->BitsPerPixel == 32 && pTexInfo->Flags.Info.TiledY &&
                        pTexInfo->MSAA.NumSamples == 1 && pTexInfo->MaxLod > 1) &&
                    UnitAlignWidth <= 4)
                 {
                     UnitAlignWidth = 8;
                 }
+
+                SET_ALIGN_FACTOR(Width, 128);
             }
             else if(pTexInfo->MSAA.NumSamples <= 1)
             {
-                if ((GmmGetWaTable(pGmmGlobalContext)->WaValign2For96bppFormats) &&
+                if ((GmmGetWaTable(pGmmLibContext)->WaValign2For96bppFormats) &&
                             ( pTexInfo->BitsPerPixel == 96 ) )
                 {
                     UnitAlignHeight = 2;
                 }
-                else if ((GmmGetWaTable(pGmmGlobalContext)->WaValign2ForR8G8B8UINTFormat) &&
+                else if ((GmmGetWaTable(pGmmLibContext)->WaValign2ForR8G8B8UINTFormat) &&
                             ( pTexInfo->Format == GMM_FORMAT_R8G8B8_UINT ) )
                 {
                     UnitAlignHeight = 2;
