@@ -194,7 +194,7 @@ void GmmLib::PageTable::AllocateL1L2Table(GMM_GFX_ADDRESS TileAddr, GMM_GFX_ADDR
         PoolElem = PageTableMgr->__GetFreePoolNode(&PoolNodeIdx, PoolType); //Recognize if Aux-L1 being allocated
         if(PoolElem)
         {
-            pL1Tbl = new GmmLib::LastLevelTable(PoolElem, PoolNodeIdx, GMM_L1_SIZE_DWORD(TTType, pGmmGlobalContext), L2eIdx); //use Aux L1_Size_DWORD
+            pL1Tbl = new GmmLib::LastLevelTable(PoolElem, PoolNodeIdx, GMM_L1_SIZE_DWORD(TTType, GetGmmLibContext()), L2eIdx); // use TR vs Aux L1_Size_DWORD
 
             if(pL1Tbl)
             {
@@ -260,7 +260,7 @@ void GmmLib::PageTable::AllocateDummyTables(GmmLib::Table **L2Table, GmmLib::Tab
         PoolElem = PageTableMgr->__GetFreePoolNode(&PoolNodeIdx, PoolType); //Recognize if Aux-L1 being allocated
         if(PoolElem)
         {
-            *L1Table = new GmmLib::LastLevelTable(PoolElem, PoolNodeIdx, GMM_L1_SIZE_DWORD(TTType, pGmmGlobalContext), 0); //use Aux L1_Size_DWORD
+            *L1Table = new GmmLib::LastLevelTable(PoolElem, PoolNodeIdx, GMM_L1_SIZE_DWORD(TTType, GetGmmLibContext()), 0); // use TR vs Aux L1_Size_DWORD
 
             if(*L1Table)
             {
@@ -296,7 +296,7 @@ void GmmLib::PageTable::GetL1L2TableAddr(GMM_GFX_ADDRESS TileAddr, GMM_GFX_ADDRE
 
     L3eIdx = GMM_L3_ENTRY_IDX(TTType, TileAddr);
     L2eIdx = GMM_L2_ENTRY_IDX(TTType, TileAddr);
-    L1eIdx = GMM_L1_ENTRY_IDX(TTType, TileAddr, pGmmGlobalContext);
+    L1eIdx = GMM_L1_ENTRY_IDX(TTType, TileAddr, GetGmmLibContext());
 
     __GMM_ASSERT(TTL3.L3Handle);
     L3TableAdr = TTL3.GfxAddress;
@@ -355,8 +355,8 @@ uint8_t GmmLib::PageTable::GetMappingType(GMM_GFX_ADDRESS GfxVA, GMM_GFX_SIZE_T
 
     L3eIdx      = GMM_L3_ENTRY_IDX(TTType, GfxVA);
     L2eIdx      = GMM_L2_ENTRY_IDX(TTType, GfxVA);
-    L1eIdx      = GMM_L1_ENTRY_IDX(TTType, GfxVA, pGmmGlobalContext);
-    L1EntrySize = !WA16K ? GMM_KBYTE(64) : GMM_KBYTE(16);
+    L1eIdx      = GMM_L1_ENTRY_IDX(TTType, GfxVA, GetGmmLibContext());
+    L1EntrySize = (!WA16K(GetGmmLibContext())) ? GMM_KBYTE(64) : GMM_KBYTE(16);
 
     EnterCriticalSection(&TTLock);
     __GMM_ASSERT(TTL3.L3Handle);
@@ -397,7 +397,7 @@ uint8_t GmmLib::PageTable::GetMappingType(GMM_GFX_ADDRESS GfxVA, GMM_GFX_SIZE_T
                 uint32_t LastBit = 0;
                 uint32_t i       = static_cast<uint32_t>(L1eIdx) / 32;
 
-                while(!bFoundLastVA && i < (uint32_t)(GMM_L1_SIZE_DWORD(TTType, pGmmGlobalContext)))
+                while(!bFoundLastVA && i < (uint32_t)(GMM_L1_SIZE_DWORD(TTType, GetGmmLibContext())))
                 {
                     uint32_t UsageDW = pL1Tbl->GetUsedEntries()[i++];
                     uint32_t BitNum  = 31;
@@ -439,7 +439,7 @@ uint8_t GmmLib::PageTable::GetMappingType(GMM_GFX_ADDRESS GfxVA, GMM_GFX_SIZE_T
                 }
                 else
                 {
-                    GMM_GFX_SIZE_T NumTiles = GMM_L1_SIZE(TTType, pGmmGlobalContext);
+                    GMM_GFX_SIZE_T NumTiles = GMM_L1_SIZE(TTType, GetGmmLibContext());
                     if(GfxVA == TileAddr)
                     {
                         MapType = false;
@@ -463,11 +463,11 @@ uint8_t GmmLib::PageTable::GetMappingType(GMM_GFX_ADDRESS GfxVA, GMM_GFX_SIZE_T
                 if(GfxVA == TileAddr)
                 {
                     MapType  = false;
-                    NumTiles = (GMM_L2_SIZE(TTType) - L2eIdx) * (GMM_L1_SIZE(TTType, pGmmGlobalContext) - L1eIdx);
+                    NumTiles = (GMM_L2_SIZE(TTType) - L2eIdx) * (GMM_L1_SIZE(TTType, GetGmmLibContext()) - L1eIdx);
                 }
                 else
                 {
-                    NumTiles = ((GMM_L2_SIZE(TTType)) * (GMM_L1_SIZE(TTType, pGmmGlobalContext)));
+                    NumTiles = ((GMM_L2_SIZE(TTType)) * (GMM_L1_SIZE(TTType, GetGmmLibContext())));
                 }
                 TileAddr += NumTiles * L1EntrySize;
                 GET_NEXT_L2TABLE(L1eIdx, L2eIdx, L3eIdx)
@@ -501,12 +501,12 @@ uint8_t GmmLib::PageTable::GetMappingType(GMM_GFX_ADDRESS GfxVA, GMM_GFX_SIZE_T
 //     true, if Table for given tile adr is all null mapped
 //     false,if Table does not exist or has non-null mapping
 //-----------------------------------------------------------------------------
-bool GmmLib::Table::TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr, bool NullMapped)
+bool GmmLib::Table::TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr, bool NullMapped, GMM_LIB_CONTEXT *pGmmLibContext )
 {
     uint32_t EntryIdx;
     uint32_t ElemNum = 0, BitNum = 0;
 
-    EntryIdx = IsL1 ? static_cast<uint32_t>(GMM_L1_ENTRY_IDX(Type, TileAdr, pGmmGlobalContext)) : static_cast<uint32_t>(GMM_L2_ENTRY_IDX(Type, TileAdr));
+    EntryIdx = IsL1 ? static_cast<uint32_t>(GMM_L1_ENTRY_IDX(Type, TileAdr, pGmmLibContext)) : static_cast<uint32_t>(GMM_L2_ENTRY_IDX(Type, TileAdr));
 
     ElemNum = EntryIdx / (sizeof(UsedEntries[0]) * 8);
     BitNum  = EntryIdx % (sizeof(UsedEntries[0]) * 8);
@@ -522,7 +522,7 @@ bool GmmLib::Table::TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS Til
 
     if(NullMapped)
     {
-        int TableDWSize = IsL1 ? static_cast<int>(GMM_L1_SIZE_DWORD(Type, pGmmGlobalContext)) : static_cast<int>(GMM_L2_SIZE_DWORD(Type));
+        int TableDWSize = IsL1 ? static_cast<int>(GMM_L1_SIZE_DWORD(Type,  pGmmLibContext)) : static_cast<int>(GMM_L2_SIZE_DWORD(Type));
         for(int i = 0; i < TableDWSize; i++)
         {
             if(UsedEntries[i])
@@ -550,10 +550,10 @@ bool GmmLib::Table::TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS Til
 //     true, if Table for given tile adr is all null mapped
 //     false,if Table has non-null mapping
 //-----------------------------------------------------------------------------
-bool GmmLib::Table::IsTableNullMapped(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr)
+bool GmmLib::Table::IsTableNullMapped(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr, GMM_LIB_CONTEXT *pGmmLibContext)
 {
     GMM_UNREFERENCED_PARAMETER(TileAdr);
-    int TableDWSize = IsL1 ? static_cast<int>(GMM_L1_SIZE_DWORD(Type, pGmmGlobalContext)) : static_cast<int>(GMM_L2_SIZE_DWORD(Type));
+    int TableDWSize = IsL1 ? static_cast<int>(GMM_L1_SIZE_DWORD(Type, pGmmLibContext)) : static_cast<int>(GMM_L2_SIZE_DWORD(Type));
     for(int i = 0; i < TableDWSize; i++)
     {
         if(UsedEntries[i])
@@ -622,7 +622,7 @@ GMM_STATUS GmmLib::GmmPageTablePool::__DestroyPageTablePool(void *DeviceCallback
         Dealloc.Priv   = Node->pGmmResInfo;
         Dealloc.hCsr   = hCsr;
 
-        Status = __GmmDeviceDealloc(ClientType, DeviceCb, &Dealloc);
+        Status = __GmmDeviceDealloc(ClientType, DeviceCb, &Dealloc, Node->pClientContext);
 
         Node->PoolHandle     = NULL;
         Node->PoolGfxAddress = 0;
@@ -656,7 +656,7 @@ GMM_STATUS GmmLib::PageTable::DestroyL3Table()
         Dealloc.Priv   = TTL3.pGmmResInfo;
         Dealloc.hCsr   = PageTableMgr->hCsr;
 
-        Status = __GmmDeviceDealloc(ClientType, &PageTableMgr->DeviceCbInt, &Dealloc);
+        Status = __GmmDeviceDealloc(ClientType, &PageTableMgr->DeviceCbInt, &Dealloc, pClientContext);
 
         TTL3.L3Handle   = NULL;
         TTL3.GfxAddress = 0;
