@@ -76,7 +76,7 @@ static inline int _BitScanForward(uint32_t *index, uint32_t mask)
 #endif
 #endif
 
-#define GMM_L1_SIZE(TTType, pGmmLibContext)       GMM_AUX_L1_SIZE(pGmmLibContext) 
+#define GMM_L1_SIZE(TTType, pGmmLibContext)  GMM_AUX_L1_SIZE(pGmmLibContext)
 #define GMM_L1_SIZE_DWORD(TTType, pGmmLibContext) GMM_AUX_L1_SIZE_DWORD(pGmmLibContext)
 #define GMM_L2_SIZE(TTType)                       GMM_AUX_L2_SIZE
 #define GMM_L2_SIZE_DWORD(TTType)                 GMM_AUX_L2_SIZE_DWORD 
@@ -94,7 +94,7 @@ static inline int _BitScanForward(uint32_t *index, uint32_t mask)
 
 //HW provides single-set of TR/Aux-TT registers for non-privileged programming
 //Engine-specific offsets are HW-updated with programmed values.
-#define GET_L3ADROFFSET(TRTT, L3AdrOffset) \
+#define GET_L3ADROFFSET(TRTT, L3AdrOffset, pGmmLibContext) \
            L3AdrOffset = 0x4200;            
 
 
@@ -275,8 +275,8 @@ namespace GmmLib
         GMM_GFX_ADDRESS GetCPUAddress() { return (PoolElem->GetCPUAddress() + (PoolNodeIdx * PAGE_SIZE)); }
         SyncInfo& GetBBInfo() { return BBInfo; }
         uint32_t* &GetUsedEntries() { return UsedEntries; }
-        bool TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr, bool NullMapped);
-        bool IsTableNullMapped(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr);
+        bool TrackTableUsage(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr, bool NullMapped,GMM_LIB_CONTEXT* pGmmLibContext);
+        bool IsTableNullMapped(TT_TYPE Type, bool IsL1, GMM_GFX_ADDRESS TileAdr,GMM_LIB_CONTEXT *pGmmLibContext);
         void UpdatePoolFence(GMM_UMD_SYNCCONTEXT * UmdContext, bool ClearNode);
     };
 
@@ -456,6 +456,8 @@ namespace GmmLib
             TTType(flag),
 	    NodesPerTable(Size / PAGE_SIZE)
         {
+            PageTableMgr = NULL;
+            pClientContext = NULL;
             InitializeCriticalSection(&TTLock);
 
             pTTL2 = new MidLevelTable[NumL3e];
@@ -467,6 +469,11 @@ namespace GmmLib
 
             DeleteCriticalSection(&TTLock);
         }
+
+	inline GMM_LIB_CONTEXT* GetGmmLibContext()
+        {
+            return pClientContext->GetLibContext();
+        }
        
         GMM_GFX_ADDRESS GetL3Address() { return TTL3.GfxAddress; }
         bool &GetRegisterStatus() { return TTL3.NeedRegisterUpdate; }
@@ -534,8 +541,8 @@ GMM_STATUS __GmmDeviceAlloc(GmmClientContext            *pClientContext,
 
 GMM_STATUS __GmmDeviceDealloc(GMM_CLIENT                ClientType,
                               GMM_DEVICE_CALLBACKS_INT  *DeviceCb,
-                              GMM_DEVICE_DEALLOC        *pDealloc);
-
+                              GMM_DEVICE_DEALLOC        *pDealloc,
+                              GmmClientContext *pClientContext);
 }
 #endif  // #ifdef __cplusplus
 
